pub trait HttpRequest {
type Body: Read;
// Required methods
fn multipart_boundary(&self) -> Option<&str>;
fn body(self) -> Self::Body;
}Expand description
A server-side HTTP request that may or may not be multipart.
May be implemented by mutable references if providing the request or body by-value is undesirable.
Required Associated Types
Required Methods
Sourcefn multipart_boundary(&self) -> Option<&str>
fn multipart_boundary(&self) -> Option<&str>
Get the boundary string of this request if it is a POST request
with the Content-Type header set to multipart/form-data.
The boundary string should be supplied as an extra value of the Content-Type header, e.g.
Content-Type: multipart/form-data; boundary={boundary}.
Implementations on Foreign Types
Sourceimpl<'r, 'a, 'b> HttpRequest for &'r mut Request<'a, 'b>
impl<'r, 'a, 'b> HttpRequest for &'r mut Request<'a, 'b>
Implementors
Sourceimpl<'a> HttpRequest for ServerRequest<'a>
Available on crate feature server only.
impl<'a> HttpRequest for ServerRequest<'a>
Available on crate feature
server only.